#[non_exhaustive]pub enum AdAdmissionError {
UnsupportedAdOrder {
order: u32,
},
NonFieldScalar,
AdRuleUnavailable,
}Expand description
Why a scalar may not be differentiated at the requested order.
This is the query result of ad_admission; it never represents a gradient.
Examples
use tenferro_tensor_core::{ad_admission, AdAdmissionError};
assert_eq!(
ad_admission::<f64>(2),
Err(AdAdmissionError::UnsupportedAdOrder { order: 2 })
);Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnsupportedAdOrder
Only first-order differentiation is admitted for a non-preset scalar.
NonFieldScalar
The scalar’s arithmetic is not a field, so the canonical field derivative rules do not apply.
The scalar is admissible in principle, but no derivative rules exist for it in this build.