promote_in_set

Function promote_in_set 

pub fn promote_in_set<Tag: Copy + PartialEq>(
    tags: &[Tag],
    specs: &[MemberSpec],
    lhs: Tag,
    rhs: Tag,
) -> Tag
Promote two members of one set from its parallel tag and fact tables.

tags and specs are emitted together in the same order by [define_scalar_tag!], so a tag that is not listed in tags (an externally defined member) promotes to itself.

Examples

use tenferro_tensor_core::{promote_in_set, DType};

assert_eq!(
    promote_in_set(DType::TAGS, DType::SPECS, DType::I32, DType::F32),
    DType::F64
);